@@ -56,6 +56,7 @@ class RegisterAgent(gaupol.Delegate):
     __metaclass__ = gaupol.Contractual
 
     def __init__(self, master):
+        """Initialize a RegisterAgent object."""
 
         gaupol.Delegate.__init__(self, master)
         self._do_description = None
@@ -81,7 +82,7 @@ class RegisterAgent(gaupol.Delegate):
             return self.undoables
         if register.shift == -1:
             return self.redoables
-        raise ValueError
+        raise ValueError("Invalid register: %s" % repr(register))
 
     def _get_source_stack(self, register):
         """Return the stack where the action to register is taken from."""
@@ -90,7 +91,7 @@ class RegisterAgent(gaupol.Delegate):
             return self.redoables
         if register.shift == -1:
             return self.undoables
-        raise ValueError
+        raise ValueError("Invalid register: %s" % repr(register))
 
     def _on_notify_undo_limit(self, *args):
         """Cut reversion stacks if limit set."""
@@ -124,6 +125,7 @@ class RegisterAgent(gaupol.Delegate):
     def _shift_changed_value(self, action, shift):
         """Shift the values of the changed attributes."""
 
+        # pylint: disable-msg=E1101
         if gaupol.documents.MAIN in action.docs:
             self.main_changed += shift
         if tuple(action.docs) == (gaupol.documents.TRAN,):
