@@ -33,6 +33,7 @@ class FormatDeterminer(gaupol.Singleton):
     __metaclass__ = gaupol.Contractual
 
     def __init__(self):
+        """Initialize a FormatDeterminer object."""
 
         self._re_ids = []
         self._compile_identifiers()
@@ -61,4 +62,5 @@ class FormatDeterminer(gaupol.Singleton):
                 for format, re_id in self._re_ids:
                     if re_id.search(line) is not None:
                         return format
-        raise gaupol.FormatError
+        raise gaupol.FormatError("Failed to detect format of file %s"
+            % repr(path))
