@@ -116,7 +116,8 @@ _encodings = (
     ("utf_16_be"      , "UTF-16BE"        , _("Unicode")            ),
     ("utf_16_le"      , "UTF-16LE"        , _("Unicode")            ),
     ("utf_7"          , "UTF-7"           , _("Unicode")            ),
-    ("utf_8"          , "UTF-8"           , _("Unicode")            ),)
+    ("utf_8"          , "UTF-8"           , _("Unicode")            ),
+    ("utf_8_sig"      , "UTF-8-SIG"       , _("Unicode")            ),)
 
 CODE, NAME, DESC = range(3)
 
@@ -124,23 +125,6 @@ CODE, NAME, DESC = range(3)
 _re_illegal = re.compile(r"[^a-z0-9_]")
 
 
-def _translate_code_ensure(value, code):
-    assert is_valid_code(value)
-
-@gaupol.deco.contractual
-def _translate_code(code):
-    """Translate weird encoding code.
-
-    Raise ValueError if not found.
-    Return normalized encoding code.
-    """
-    code = _re_illegal.sub("_", code.lower())
-    code = gaupol.util.get_encoding_alias(code)
-    for item in _encodings:
-        if item[CODE] == code:
-            return item[CODE]
-    raise ValueError
-
 def code_to_description(code):
     """Convert encoding code to localized description.
 
@@ -149,7 +133,7 @@ def code_to_description(code):
     for item in _encodings:
         if item[CODE] == code:
             return item[DESC]
-    raise ValueError
+    raise ValueError("Code %s not found" % repr(code))
 
 def code_to_long_name(code):
     """Convert encoding code to localized long name.
@@ -161,7 +145,7 @@ def code_to_long_name(code):
         if item[CODE] == code:
             name, description = item[NAME], item[DESC]
             return _("%(description)s (%(name)s)") % locals()
-    raise ValueError
+    raise ValueError("Code %s not found" % repr(code))
 
 def code_to_name(code):
     """Convert encoding code to name.
@@ -171,7 +155,7 @@ def code_to_name(code):
     for item in _encodings:
         if item[CODE] == code:
             return item[NAME]
-    raise ValueError
+    raise ValueError("Code %s not found" % repr(code))
 
 def detect_ensure(value, path):
     if value is not None:
@@ -196,10 +180,36 @@ def detect(path):
         # chardet returns what seem to be IANA names. They need to be
         # translated to their Python equivalents. Some of the encodings
         # returned by chardet are not supported by Python.
-        return _translate_code(code)
+        return translate_code(code)
     except ValueError:
         return None
 
+def detect_bom_ensure(value, path):
+    if value is not None:
+        assert is_valid_code(value)
+
+@gaupol.deco.contractual
+def detect_bom(path):
+    """Return corresponding encoding if BOM found, else None."""
+
+    line = open(path, "r").readline()
+    if (line.startswith(codecs.BOM_UTF32_BE) and
+        is_valid_code("utf_32_be")):
+        return "utf_32_be"
+    if (line.startswith(codecs.BOM_UTF32_LE) and
+        is_valid_code("utf_32_le")):
+        return "utf_32_le"
+    if (line.startswith(codecs.BOM_UTF8) and
+        is_valid_code("utf_8_sig")):
+        return "utf_8_sig"
+    if (line.startswith(codecs.BOM_UTF16_BE) and
+        is_valid_code("utf_16_be")):
+        return "utf_16_be"
+    if (line.startswith(codecs.BOM_UTF16_LE) and
+        is_valid_code("utf_16_le")):
+        return "utf_16_le"
+    return None
+
 def get_locale_code_ensure(value):
     if value is not None:
         assert is_valid_code(value)
@@ -257,4 +267,21 @@ def name_to_code(name):
     for item in _encodings:
         if item[NAME] == name:
             return item[CODE]
-    raise ValueError
+    raise ValueError("Name %s not found" % repr(name))
+
+def translate_code_ensure(value, code):
+    assert is_valid_code(value)
+
+@gaupol.deco.contractual
+def translate_code(code):
+    """Translate weird encoding code.
+
+    Raise ValueError if not found.
+    Return normalized encoding code.
+    """
+    code = _re_illegal.sub("_", code.lower())
+    code = gaupol.util.get_encoding_alias(code)
+    for item in _encodings:
+        if item[CODE] == code:
+            return item[CODE]
+    raise ValueError("Code %s not found" % repr(code))
