@@ -22,6 +22,7 @@ import codecs
 import contextlib
 import gaupol
 import os
+import sys
 
 __all__ = ("SubtitleFile",)
 
@@ -78,10 +79,11 @@ class SubtitleFile(object):
         Raise UnicodeError if decoding fails.
         Return a list of the lines.
         """
-        args = (self.path, "rU", self.encoding)
-        with contextlib.closing(codecs.open(*args)) as fobj:
-            lines = fobj.readlines()
+        decode = lambda x: x.decode(self.encoding)
+        with contextlib.closing(open(self.path, "rU")) as fobj:
+            lines = map(decode, fobj.readlines())
             chars = fobj.newlines
+            assert chars is not None
         lines = [x[:-1] if x.endswith("\n") else x for x in lines]
         for index in (0, -1):
             while lines and (not lines[index].strip()):
@@ -127,17 +129,21 @@ class SubtitleFile(object):
         assert self.format.has_header
 
     def get_template_header(self):
-        """Read and return the header from a template file."""
+        """Read and return the header from a template file.
 
+        Raise IOError if reading global header file fails.
+        Raise UnicodeError if decoding global header file fails.
+        """
         basename = self.format.name.lower()
-        read = gaupol.deco.silent(IOError, UnicodeError)(gaupol.util.read)
         directory = os.path.join(gaupol.DATA_HOME_DIR, "headers")
         path = os.path.join(directory, basename)
         if os.path.isfile(path):
-            return read(path, None)
+            try: return gaupol.util.read(path, None)
+            except (IOError, UnicodeError):
+                gaupol.util.print_read_io(sys.exc_info(), path)
         directory = os.path.join(gaupol.DATA_DIR, "headers")
         path = os.path.join(directory, basename)
-        return read(path, "ascii")
+        return gaupol.util.read(path, "ascii")
 
     def read(self):
         """Read file and return subtitles.
