@@ -34,6 +34,7 @@ class SubStationAlpha(gaupol.SubtitleFile):
     mode = gaupol.modes.TIME
 
     def __init__(self, path, encoding, newline=None):
+        """Initialize a SubStationAlpha object."""
 
         gaupol.SubtitleFile.__init__(self, path, encoding, newline)
         self.event_fields = ("Marked", "Start", "End", "Style", "Name",
@@ -75,7 +76,7 @@ class SubStationAlpha(gaupol.SubtitleFile):
             return self._re_subtitle_time.sub(r"\1\2", value)
         if field_name == "Text":
             value = subtitle.get_text(doc)
-            return value.replace("\n", "\\n")
+            return value.replace("\n", "\\N")
         if field_name in ("MarginL", "MarginR", "MarginV"):
             name = gaupol.util.title_to_lower_case(field_name)
             return "%04d" % getattr(subtitle.ssa, name)
@@ -93,10 +94,11 @@ class SubStationAlpha(gaupol.SubtitleFile):
         self.header = self.header.strip()
 
     def copy_from(self, other):
-        """Copy generic properties from file of same format."""
+        """Copy generic properties from other file."""
 
         gaupol.SubtitleFile.copy_from(self, other)
-        self.event_fields = tuple(other.event_fields)
+        if self.format == other.format:
+            self.event_fields = tuple(other.event_fields)
 
     def read(self):
         """Read file and return subtitles.
