@@ -48,14 +48,18 @@ from gaupol.gtk.fields import *
 from gaupol.gtk.styles import *
 from gaupol.gtk.targets import *
 from gaupol.gtk.units import *
+from gaupol.gtk.enumuim import *
 from gaupol.gtk.errors import *
 from gaupol.gtk import conf
+from gaupol.gtk.conf import *
 from gaupol.gtk import ruler
 from gaupol.gtk import util
 from gaupol.gtk.meta import *
 from gaupol.gtk.runner import *
 from gaupol.gtk.entries import *
 from gaupol.gtk.renderers import *
+from gaupol.gtk.extension import *
+from gaupol.gtk.extensionman import *
 from gaupol.gtk.output import *
 from gaupol.gtk.view import *
 from gaupol.gtk.page import *
