@@ -26,9 +26,11 @@ class ShowCaseMenuAction(gaupol.gtk.MenuAction):
     """Show the case format menu."""
 
     def __init__(self):
+        """Initialize a ShowCaseMenuAction object."""
 
         gaupol.gtk.MenuAction.__init__(self, "show_case_menu")
         self.props.label = _("Ca_se")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -44,12 +46,14 @@ class ToggleDialogDashesAction(gaupol.gtk.Action):
     """Toggle dialogue dashes on the selected texts."""
 
     def __init__(self):
+        """Initialize a ToggleDialogDashesAction object."""
 
         gaupol.gtk.Action.__init__(self, "toggle_dialogue_dashes")
         self.props.label = _("_Dialogue")
         tooltip = _("Add or remove dialogue dashes on the selected texts")
         self.props.tooltip = tooltip
         self.accelerator = "D"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -65,12 +69,14 @@ class ToggleItalicizationAction(gaupol.gtk.Action):
     """Toggle italicization of the selected texts."""
 
     def __init__(self):
+        """Initialize a ToggleItalicizationAction object."""
 
         gaupol.gtk.Action.__init__(self, "toggle_italicization")
         self.props.label = _("_Italic")
         self.props.stock_id = gtk.STOCK_ITALIC
         self.props.tooltip = _("Italicize or unitalicize the selected texts")
         self.accelerator = "I"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -90,10 +96,12 @@ class UseLowerCaseAction(gaupol.gtk.Action):
     """Change the selected texts to lower case."""
 
     def __init__(self):
+        """Initialize a UseLowerCaseAction object."""
 
         gaupol.gtk.Action.__init__(self, "use_lower_case")
         self.props.label = _("_Lower")
         self.props.tooltip = _("Change the selected texts to lower case")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -109,10 +117,12 @@ class UseSentenceCaseAction(gaupol.gtk.Action):
     """Change the selected texts to sentence case."""
 
     def __init__(self):
+        """Initialize a UseSentenceCaseAction object."""
 
         gaupol.gtk.Action.__init__(self, "use_sentence_case")
         self.props.label = _("_Sentence")
         self.props.tooltip = _("Change the selected texts to sentence case")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -128,10 +138,12 @@ class UseTitleCaseAction(gaupol.gtk.Action):
     """Change the selected texts to title case."""
 
     def __init__(self):
+        """Initialize a UseTitleCaseAction object."""
 
         gaupol.gtk.Action.__init__(self, "use_title_case")
         self.props.label = _("_Title")
         self.props.tooltip = _("Change the selected texts to title case")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -145,10 +157,12 @@ class UseTitleCaseAction(gaupol.gtk.Action):
 class UseUpperCaseAction(gaupol.gtk.Action):
 
     def __init__(self):
+        """Initialize a UseUpperCaseAction object."""
 
         gaupol.gtk.Action.__init__(self, "use_upper_case")
         self.props.label = _("_Upper")
         self.props.tooltip = _("Change the selected texts to upper case")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
