@@ -25,9 +25,11 @@ class ShowEditMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'Edit' menu."""
 
     def __init__(self):
+        """Initialize a ShowEditMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_edit_menu")
         self.props.label = _("_Edit")
+        self.action_group = "main-safe"
 
 
 class ShowFileMenuAction(gaupol.gtk.TopMenuAction):
@@ -35,9 +37,11 @@ class ShowFileMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'File' menu."""
 
     def __init__(self):
+        """Initialize a ShowFileMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_file_menu")
         self.props.label = _("_File")
+        self.action_group = "main-safe"
 
 
 class ShowHelpMenuAction(gaupol.gtk.TopMenuAction):
@@ -45,9 +49,11 @@ class ShowHelpMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'Help' menu."""
 
     def __init__(self):
+        """Initialize a ShowHelpMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_help_menu")
         self.props.label = _("_Help")
+        self.action_group = "main-safe"
 
 
 class ShowProjectsMenuAction(gaupol.gtk.TopMenuAction):
@@ -55,9 +61,11 @@ class ShowProjectsMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'Projects' menu."""
 
     def __init__(self):
+        """Initialize a ShowProjectsMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_projects_menu")
         self.props.label = _("_Projects")
+        self.action_group = "main-safe"
 
 
 class ShowTextMenuAction(gaupol.gtk.TopMenuAction):
@@ -65,9 +73,11 @@ class ShowTextMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'Text' menu."""
 
     def __init__(self):
+        """Initialize a ShowTextMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_text_menu")
         self.props.label = _("_Text")
+        self.action_group = "main-safe"
 
 
 class ShowToolsMenuAction(gaupol.gtk.TopMenuAction):
@@ -75,9 +85,11 @@ class ShowToolsMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'Tools' menu."""
 
     def __init__(self):
+        """Initialize a ShowToolsMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_tools_menu")
         self.props.label = _("T_ools")
+        self.action_group = "main-safe"
 
 
 class ShowViewMenuAction(gaupol.gtk.TopMenuAction):
@@ -85,9 +97,11 @@ class ShowViewMenuAction(gaupol.gtk.TopMenuAction):
     """Show the 'View' menu."""
 
     def __init__(self):
+        """Initialize a ShowViewMenuAction object."""
 
         gaupol.gtk.TopMenuAction.__init__(self, "show_view_menu")
         self.props.label = _("_View")
+        self.action_group = "main-safe"
 
 
 __all__ = gaupol.util.get_all(dir(), r"Action$")
