@@ -26,10 +26,12 @@ class AdjustDurationsAction(gaupol.gtk.Action):
     """Lengthen or shorten durations."""
 
     def __init__(self):
+        """Initialize an AdjustDurationsAction object."""
 
         gaupol.gtk.Action.__init__(self, "adjust_durations")
         self.props.label = _("Adjust _Durations\342\200\246")
         self.props.tooltip = _("Lengthen or shorten durations")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -42,10 +44,12 @@ class ConvertFramerateAction(gaupol.gtk.Action):
     """Convert framerate."""
 
     def __init__(self):
+        """Initialize a ConvertFramerateAction object."""
 
         gaupol.gtk.Action.__init__(self, "convert_framerate")
         self.props.label = _("Convert _Framerate\342\200\246")
         self.props.tooltip = _("Change positions for a different framerate")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -59,6 +63,7 @@ class PreviewAction(gaupol.gtk.Action):
     """Preview from selected position with a video player."""
 
     def __init__(self):
+        """Initialize a PreviewAction object."""
 
         gaupol.gtk.Action.__init__(self, "preview")
         self.props.label = _("_Preview")
@@ -66,6 +71,7 @@ class PreviewAction(gaupol.gtk.Action):
         tooltip = _("Preview from selected position with a video player")
         self.props.tooltip = tooltip
         self.accelerator = "P"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -86,11 +92,13 @@ class ShiftPositionsAction(gaupol.gtk.Action):
     """Make subtitles appear earlier or later."""
 
     def __init__(self):
+        """Initialize a ShiftPositionsAction object."""
 
         gaupol.gtk.Action.__init__(self, "shift_positions")
         self.props.label = _("_Shift Positions\342\200\246")
         self.props.tooltip = _("Make subtitles appear earlier or later")
         self.accelerator = "H"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -103,11 +111,13 @@ class TransformPositionsAction(gaupol.gtk.Action):
     """Change positions by linear two-point correction."""
 
     def __init__(self):
+        """Initialize a TransformPositionsAction object."""
 
         gaupol.gtk.Action.__init__(self, "transform_positions")
         self.props.label = _("_Transform Positions\342\200\246")
         tooltip = _("Change positions by linear two-point correction")
         self.props.tooltip = tooltip
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
