@@ -25,11 +25,13 @@ class ActivateNextProjectAction(gaupol.gtk.Action):
     """Activate the project in the next tab."""
 
     def __init__(self):
+        """Initialize an ActivateNextProjectAction object."""
 
         gaupol.gtk.Action.__init__(self, "activate_next_project")
         self.props.label = _("_Next")
         self.props.tooltip = _("Activate the project in the next tab")
         self.accelerator = "<Control>Page_Down"
+        self.action_group = "main-safe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -44,11 +46,13 @@ class ActivatePreviousProjectAction(gaupol.gtk.Action):
     """Activate the project in the previous tab."""
 
     def __init__(self):
+        """Initialize an ActivatePreviousProjectAction object."""
 
         gaupol.gtk.Action.__init__(self, "activate_previous_project")
         self.props.label = _("_Previous")
         self.props.tooltip = _("Activate the project in the previous tab")
         self.accelerator = "<Control>Page_Up"
+        self.action_group = "main-safe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -62,10 +66,12 @@ class MoveTabLeftAction(gaupol.gtk.Action):
     """Move the current tab to the left."""
 
     def __init__(self):
+        """Initialize a MoveTabLeftAction object."""
 
         gaupol.gtk.Action.__init__(self, "move_tab_left")
         self.props.label = _("Move Tab _Left")
         self.props.tooltip = _("Move the current tab to the left")
+        self.action_group = "main-safe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -79,10 +85,12 @@ class MoveTabRightAction(gaupol.gtk.Action):
     """Move the current tab to the right."""
 
     def __init__(self):
+        """Initialize a MoveTabRightAction object."""
 
         gaupol.gtk.Action.__init__(self, "move_tab_right")
         self.props.label = _("Move Tab _Right")
         self.props.tooltip = _("Move the current tab to the right")
+        self.action_group = "main-safe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -96,9 +104,11 @@ class ShowColumnsMenuAction(gaupol.gtk.MenuAction):
 
     """Show the columns view menu."""
     def __init__(self):
+        """Initialize a ShowColumnsMenuAction object."""
 
         gaupol.gtk.MenuAction.__init__(self, "show_columns_menu")
         self.props.label = _("_Columns")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -111,6 +121,7 @@ class ShowFramerate24Action(gaupol.gtk.RadioAction):
     """Change the framerate to 24 fps."""
 
     def __init__(self):
+        """Initialize a ShowFramerate24Action object."""
 
         gaupol.gtk.RadioAction.__init__(self, "show_framerate_24")
         framerate = gaupol.gtk.conf.editor.framerate
@@ -119,6 +130,7 @@ class ShowFramerate24Action(gaupol.gtk.RadioAction):
         tooltip = _("Calculate nonnative units with framerate 24 fps")
         self.props.tooltip = tooltip
         self.props.value = gaupol.framerates.FPS_24
+        self.action_group = "main-unsafe"
         self.framerate = gaupol.framerates.FPS_24
         self.group = "ShowFramerate24Action"
 
@@ -134,6 +146,7 @@ class ShowFramerate25Action(gaupol.gtk.RadioAction):
     """Change the framerate to 25 fps."""
 
     def __init__(self):
+        """Initialize a ShowFramerate25Action object."""
 
         gaupol.gtk.RadioAction.__init__(self, "show_framerate_25")
         framerate = gaupol.gtk.conf.editor.framerate
@@ -142,6 +155,7 @@ class ShowFramerate25Action(gaupol.gtk.RadioAction):
         tooltip = _("Calculate nonnative units with framerate 25 fps")
         self.props.tooltip = tooltip
         self.props.value = gaupol.framerates.FPS_25
+        self.action_group = "main-unsafe"
         self.framerate = gaupol.framerates.FPS_25
         self.group = "ShowFramerate24Action"
 
@@ -157,6 +171,7 @@ class ShowFramerate30Action(gaupol.gtk.RadioAction):
     """Change the framerate to 30 fps."""
 
     def __init__(self):
+        """Initialize a ShowFramerate30Action object."""
 
         gaupol.gtk.RadioAction.__init__(self, "show_framerate_30")
         framerate = gaupol.gtk.conf.editor.framerate
@@ -165,6 +180,7 @@ class ShowFramerate30Action(gaupol.gtk.RadioAction):
         tooltip = _("Calculate nonnative units with framerate 30 fps")
         self.props.tooltip = tooltip
         self.props.value = gaupol.framerates.FPS_30
+        self.action_group = "main-unsafe"
         self.framerate = gaupol.framerates.FPS_30
         self.group = "ShowFramerate24Action"
 
@@ -180,9 +196,11 @@ class ShowFramerateMenuAction(gaupol.gtk.MenuAction):
     """Show the framerate view menu."""
 
     def __init__(self):
+        """Initialize a ShowFramerateMenuAction object."""
 
         gaupol.gtk.MenuAction.__init__(self, "show_framerate_menu")
         self.props.label = _("F_ramerate")
+        self.action_group = "main-unsafe"
         self.widgets = ("framerate_combo",)
 
     def _affirm_doable(self, application, page):
@@ -197,6 +215,7 @@ class ShowFramesAction(gaupol.gtk.RadioAction):
     """Show positions as frames."""
 
     def __init__(self):
+        """Initialize a ShowFramesAction object."""
 
         gaupol.gtk.RadioAction.__init__(self, "show_frames")
         mode = gaupol.gtk.conf.editor.mode
@@ -205,6 +224,7 @@ class ShowFramesAction(gaupol.gtk.RadioAction):
         self.props.tooltip = _("Show positions as frames")
         self.props.value = gaupol.modes.FRAME
         self.accelerator = "<Shift>T"
+        self.action_group = "main-unsafe"
         self.group = "ShowTimesAction"
         self.mode = gaupol.modes.FRAME
 
@@ -219,6 +239,7 @@ class ShowTimesAction(gaupol.gtk.RadioAction):
     """Show positions as times."""
 
     def __init__(self):
+        """Initialize a ShowTimesAction object."""
 
         gaupol.gtk.RadioAction.__init__(self, "show_times")
         mode = gaupol.gtk.conf.editor.mode
@@ -227,6 +248,7 @@ class ShowTimesAction(gaupol.gtk.RadioAction):
         self.props.tooltip = _("Show positions as times")
         self.props.value = gaupol.modes.TIME
         self.accelerator = "T"
+        self.action_group = "main-unsafe"
         self.group = "ShowTimesAction"
         self.mode = gaupol.modes.TIME
 
@@ -241,12 +263,14 @@ class ToggleDurationColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'Duration' column."""
 
     def __init__(self):
+        """Initialize a ToggleDurationColumnAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_duration_column")
         fields = gaupol.gtk.conf.editor.visible_fields
         self.props.active = gaupol.gtk.fields.DURATION in fields
         self.props.label = _("_Duration")
         self.props.tooltip = _('Show or hide the "Duration" column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -259,12 +283,14 @@ class ToggleEndColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'End' column."""
 
     def __init__(self):
+        """Initialize a ToggleEndColumnAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_end_column")
         fields = gaupol.gtk.conf.editor.visible_fields
         self.props.active = gaupol.gtk.fields.END in fields
         self.props.label = _("_End")
         self.props.tooltip = _('Show or hide the "End" column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -277,12 +303,14 @@ class ToggleMainTextColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'Main Text' column."""
 
     def __init__(self):
+        """Initialize a ToggleMainTextColumnAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_main_text_column")
         fields = gaupol.gtk.conf.editor.visible_fields
         self.props.active = gaupol.gtk.fields.MAIN_TEXT in fields
         self.props.label = _("_Main Text")
         self.props.tooltip = _('Show or hide the "Main Text" column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -295,12 +323,14 @@ class ToggleMainToolbarAction(gaupol.gtk.ToggleAction):
     """Show or hide the main toolbar."""
 
     def __init__(self):
+        """Initialize a ToggleMainToolbarAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_main_toolbar")
         show = gaupol.gtk.conf.application_window.show_main_toolbar
         self.props.active = show
         self.props.label = _("_Main Toolbar")
         self.props.tooltip = _("Show or hide the main toolbar")
+        self.action_group = "main-safe"
 
 
 class ToggleNumberColumnAction(gaupol.gtk.ToggleAction):
@@ -308,12 +338,14 @@ class ToggleNumberColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'No.' column."""
 
     def __init__(self):
+        """Initialize a ToggleNumberColumnAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_number_column")
         fields = gaupol.gtk.conf.editor.visible_fields
         self.props.active = gaupol.gtk.fields.NUMBER in fields
         self.props.label = _("_No.")
         self.props.tooltip = _('Show or hide the "No." column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -326,11 +358,13 @@ class ToggleOutputWindowAction(gaupol.gtk.ToggleAction):
     """Show or hide the output window."""
 
     def __init__(self):
+        """Initialize a ToggleOutputWindowAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_output_window")
         self.props.active = gaupol.gtk.conf.output_window.show
         self.props.label = _("_Output Window")
         self.props.tooltip = _("Show or hide the output window")
+        self.action_group = "main-safe"
 
 
 class ToggleStartColumnAction(gaupol.gtk.ToggleAction):
@@ -338,12 +372,14 @@ class ToggleStartColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'Start' column."""
 
     def __init__(self):
+        """Initialize a ToggleStartColumnAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_start_column")
         fields = gaupol.gtk.conf.editor.visible_fields
         self.props.active = gaupol.gtk.fields.START in fields
         self.props.label = _("_Start")
         self.props.tooltip = _('Show or hide the "Start" column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -356,11 +392,13 @@ class ToggleStatusbarAction(gaupol.gtk.ToggleAction):
     """Show or hide the statusbar."""
 
     def __init__(self):
+        """Initialize a ToggleStatusbarAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_statusbar")
         self.props.active = gaupol.gtk.conf.application_window.show_statusbar
         self.props.label = _("_Statusbar")
         self.props.tooltip = _("Show or hide the statusbar")
+        self.action_group = "main-safe"
 
 
 class ToggleTranslationTextColumnAction(gaupol.gtk.ToggleAction):
@@ -368,6 +406,7 @@ class ToggleTranslationTextColumnAction(gaupol.gtk.ToggleAction):
     """Show or hide the 'Translation Text' column."""
 
     def __init__(self):
+        """Initialize a ToggleTranslationTextColumnAction object."""
 
         name = "toggle_translation_text_column"
         gaupol.gtk.ToggleAction.__init__(self, name)
@@ -375,6 +414,7 @@ class ToggleTranslationTextColumnAction(gaupol.gtk.ToggleAction):
         self.props.active = gaupol.gtk.fields.TRAN_TEXT in fields
         self.props.label = _("_Translation Text")
         self.props.tooltip = _('Show or hide the "Translation Text" column')
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -387,12 +427,14 @@ class ToggleVideoToolbarAction(gaupol.gtk.ToggleAction):
     """Show or hide the video toolbar."""
 
     def __init__(self):
+        """Initialize a ToggleVideoToolbarAction object."""
 
         gaupol.gtk.ToggleAction.__init__(self, "toggle_video_toolbar")
         show = gaupol.gtk.conf.application_window.show_video_toolbar
         self.props.active = show
         self.props.label = _("_Video Toolbar")
         self.props.tooltip = _("Show or hide the video toolbar")
+        self.action_group = "main-safe"
 
 
 __all__ = gaupol.util.get_all(dir(), r"Action$")
