@@ -37,6 +37,7 @@ class UpdateAgent(gaupol.Delegate):
     __metaclass__ = gaupol.Contractual
 
     def __init__(self, master):
+        """Initialize an UpdateAgent object."""
 
         gaupol.Delegate.__init__(self, master)
         self._message_id = None
@@ -52,7 +53,10 @@ class UpdateAgent(gaupol.Delegate):
     def _update_actions(self, page):
         """Update sensitivities of all UI manager actions for page."""
 
-        action_group = self.get_action_group("main")
+        action_group = self.get_action_group("main-safe")
+        for action in action_group.list_actions():
+            action.update_sensitivity(self, page)
+        action_group = self.get_action_group("main-unsafe")
         for action in action_group.list_actions():
             action.update_sensitivity(self, page)
 
@@ -149,6 +153,7 @@ class UpdateAgent(gaupol.Delegate):
         page = self.pages[index]
         self.update_gui()
         page.view.grab_focus()
+        self.emit("page-switched", page)
 
     def on_view_button_press_event(self, view, event):
         """Display a right-click pop-up menu to edit data."""
@@ -199,6 +204,7 @@ class UpdateAgent(gaupol.Delegate):
         """Update widget sensitivities and states for the current page."""
 
         page = self.get_current_page()
+        self.extension_manager.update_extensions(page)
         self._update_actions(page)
         self._update_widgets(page)
         self._update_revert(page)
