@@ -42,7 +42,11 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
      * page-added (application, page)
      * page-changed (application, page)
      * page-closed (application, page)
+     * page-switched (application, page)
      * pages-reordered (application, page, number)
+     * preview-completed (application, page)
+     * preview-started (application, page)
+     * quit (application)
      * text-assistant-request-pages (application, assistant)
 
     See gaupol.gtk.agents for application methods provided by agents.
@@ -54,19 +58,26 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
         "page-added",
         "page-changed",
         "page-closed",
+        "page-switched",
         "pages-reordered",
+        "preview-completed",
+        "preview-started",
+        "quit",
         "text-assistant-request-pages",)
 
     def __getattr__(self, name):
+        """Return method delegated to an agent."""
 
         return self._delegations[name]
 
     def __init__(self):
+        """Initialize an Application object."""
 
         gaupol.Observable.__init__(self)
         self._delegations = {}
         self.clipboard = gaupol.Clipboard()
         self.counter = itertools.count(1)
+        self.extension_manager = gaupol.gtk.ExtensionManager(self)
         self.framerate_combo = None
         self.notebook = None
         self.output_window = None
@@ -83,11 +94,18 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
 
         self._init_delegations()
         self._init_gui()
+        self.extension_manager.find_extensions()
+        self.extension_manager.setup_extensions()
+        self.update_gui()
+        self.window.show()
 
     def _finalize_uim_actions(self):
         """Connect actions to widgets and methods."""
 
-        action_group = self.get_action_group("main")
+        action_group = self.get_action_group("main-safe")
+        for action in action_group.list_actions():
+            action.finalize(self)
+        action_group = self.get_action_group("main-unsafe")
         for action in action_group.list_actions():
             action.finalize(self)
 
@@ -103,7 +121,8 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
             for attr_name in attr_names:
                 attr_value = getattr(agent, attr_name)
                 if attr_name in self._delegations:
-                    raise ValueError("Agents overlap")
+                    raise ValueError("Multiple definitions of %s" 
+                        % repr(attr_name))
                 self._delegations[attr_name] = attr_value
 
     def _init_framerate_combo(self):
@@ -136,7 +155,6 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
         self._init_uim()
         self._init_menubar(vbox)
         self._init_main_toolbar(vbox)
-        self._init_recent_menus()
         self._init_notebook(vbox)
         self._init_video_toolbar(vbox)
         self._init_statusbar(vbox)
@@ -144,10 +162,9 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
         self.window.add(vbox)
         vbox.show_all()
         self._init_visibilities()
-        self.set_menu_notify_events("main")
+        self.set_menu_notify_events("main-safe")
+        self.set_menu_notify_events("main-unsafe")
         self._finalize_uim_actions()
-        self.update_gui()
-        self.window.show()
 
     def _init_main_toolbar(self, vbox):
         """Initialize the main toolbar."""
@@ -201,14 +218,6 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
         gaupol.util.connect(self, "output_window", "notify::visible")
         self.output_window.props.visible = gaupol.gtk.conf.output_window.show
 
-    def _init_recent_menus(self):
-        """Initialize the recent file menus."""
-
-        item = self.get_menu_item("show_recent_main_menu")
-        item.set_submenu(gtk.Menu())
-        item = self.get_menu_item("show_recent_translation_menu")
-        item.set_submenu(gtk.Menu())
-
     def _init_redo_button(self):
         """Initialize the redo button on the main toolbar."""
 
@@ -230,12 +239,19 @@ class Application(gaupol.Observable, gaupol.gtk.Runner):
         """Initialize the UI manager."""
 
         self.uim = gtk.UIManager()
-        action_group = gtk.ActionGroup("main")
+        safe_group = gtk.ActionGroup("main-safe")
+        unsafe_group = gtk.ActionGroup("main-unsafe")
         for name in gaupol.gtk.actions.__all__:
             action = getattr(gaupol.gtk.actions, name)()
-            action_group.add_action_with_accel(action, action.accelerator)
-        self._init_uim_radio_groups(action_group)
-        self.uim.insert_action_group(action_group, 0)
+            args = (action, action.accelerator)
+            if action.action_group == "main-safe":
+                safe_group.add_action_with_accel(*args)
+            elif action.action_group == "main-unsafe":
+                unsafe_group.add_action_with_accel(*args)
+        self._init_uim_radio_groups(safe_group)
+        self._init_uim_radio_groups(unsafe_group)
+        self.uim.insert_action_group(safe_group, 0)
+        self.uim.insert_action_group(unsafe_group, 1)
         action_group = gtk.ActionGroup("projects")
         self.uim.insert_action_group(action_group, -1)
         ui_xml_file = os.path.join(gaupol.DATA_DIR, "ui", "ui.xml")
