@@ -40,6 +40,7 @@ class AboutDialog(gtk.AboutDialog):
     """Dialog for displaying credits and information."""
 
     def __init__(self, parent):
+        """Initialize an AboutDialog object."""
 
         gtk.AboutDialog.__init__(self)
         gtk.about_dialog_set_url_hook(self._on_url_clicked)
@@ -47,7 +48,7 @@ class AboutDialog(gtk.AboutDialog):
         self.set_title(_("About Gaupol"))
         self.set_program_name("Gaupol")
         self.set_version(gaupol.__version__)
-        self.set_copyright(u"Copyright \xa9 2005-2008 Osmo Salomaa")
+        self.set_copyright(u"Copyright \xa9 2005-2009 Osmo Salomaa")
         self.set_comments(_("Subtitle editor"))
         self.set_license(_license)
         self.set_wrap_license(True)
@@ -65,7 +66,7 @@ class AboutDialog(gtk.AboutDialog):
         # lines seperated by newlines (\n).
         self.set_translator_credits(_("translator-credits"))
 
-    def _on_url_clicked(self, *args):
+    def _on_url_clicked(self, dialog, url):
         """Open website in a web browser."""
 
-        gaupol.util.browse_url(gaupol.HOMEPAGE_URL)
+        gaupol.util.browse_url(url)
