@@ -28,6 +28,7 @@ class DurationAdjustDialog(gaupol.gtk.GladeDialog):
     """Dialog for lengthening or shortening durations."""
 
     def __init__(self, parent, application):
+        """Initialize a DurationAdjustDialog object."""
 
         gaupol.gtk.GladeDialog.__init__(self, "duration.glade")
         get_widget = self._glade_xml.get_widget
@@ -81,7 +82,7 @@ class DurationAdjustDialog(gaupol.gtk.GladeDialog):
             return gaupol.gtk.targets.CURRENT
         if self._all_radio.get_active():
             return gaupol.gtk.targets.ALL
-        raise ValueError
+        raise ValueError("Invalid target radio state")
 
     def _init_sensitivities(self):
         """Initialize the sensitivities of widgets."""
