@@ -27,6 +27,7 @@ class FramerateConvertDialog(gaupol.gtk.GladeDialog):
     """Dialog for converting framerates."""
 
     def __init__(self, parent, application):
+        """Initialize a FramerateConvertDialog object."""
 
         gaupol.gtk.GladeDialog.__init__(self, "framerate.glade")
         get_widget = self._glade_xml.get_widget
@@ -59,7 +60,7 @@ class FramerateConvertDialog(gaupol.gtk.GladeDialog):
             return gaupol.gtk.targets.CURRENT
         if self._all_radio.get_active():
             return gaupol.gtk.targets.ALL
-        raise ValueError
+        raise ValueError("Invalid target radio state")
 
     def _init_signal_handlers(self):
         """Initialize signal handlers."""
