@@ -72,6 +72,10 @@ def _init_application(opts, args):
         jump_row = (max(0, int(arg[1:]) - 1) if arg[1:] else -1)
         args.remove(arg)
     paths = [os.path.abspath(x) for x in args]
+    if not opts.encoding in (None, "auto"):
+        try: opts.encoding = gaupol.encodings.translate_code(opts.encoding)
+        except ValueError:
+            raise SystemExit("Unrecognized encoding: %s" % repr(opts.encoding))
     application.open_main_files(paths, opts.encoding)
     page = application.get_current_page()
     if (page is not None) and opts.translation_file:
@@ -90,7 +94,7 @@ def _init_application(opts, args):
 def _init_configuration(path):
     """Initialize the configuration module from saved values."""
 
-    default = os.path.join(gaupol.PROFILE_DIR, "gaupol.gtk.conf")
+    default = os.path.join(gaupol.CONFIG_HOME_DIR, "gaupol.gtk.conf")
     path = (default if path is None else path)
     gaupol.gtk.conf.config_file = os.path.abspath(path)
     gaupol.gtk.conf.read()
@@ -202,6 +206,7 @@ def main(args):
         return _list_encodings()
     if opts.version:
         return _show_version()
+    gaupol.paths.xdg_copy_if_applicable()
     _init_configuration(opts.config_file)
     _init_application(opts, args)
     import gtk
