@@ -9,17 +9,17 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
 """Metaclass for contractual GObjects."""
 
 import gaupol
 import gobject
 
-__all__ = ["ContractualGObject"]
+__all__ = ("ContractualGObject",)
 
 
 class ContractualGObject(gobject.GObjectMeta, gaupol.Contractual):
