@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2007 Osmo Salomaa
+# Copyright (C) 2005-2008 Osmo Salomaa
 #
 # This file is part of Gaupol.
 #
@@ -9,26 +9,23 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
-import gobject
+import gaupol.gtk
 import gtk
 
-from gaupol.gtk.unittest import TestCase
-from .. import time
 
+class TestTimeCellRenderer(gaupol.gtk.TestCase):
 
-class TestTimeCellRenderer(TestCase):
-
-    def run(self):
+    def run__renderer(self):
 
         tree_view = gtk.TreeView()
         tree_view.set_headers_visible(False)
-        store = gtk.ListStore(gobject.TYPE_STRING)
-        store.append(["12:34:56.789"])
+        store = gtk.ListStore(str)
+        store.append(("12:34:56.789",))
         tree_view.set_model(store)
         self.renderer.props.editable = True
         column = gtk.TreeViewColumn("", self.renderer, text=0)
@@ -44,8 +41,4 @@ class TestTimeCellRenderer(TestCase):
 
     def setup_method(self, method):
 
-        self.renderer = time.TimeCellRenderer()
-
-    def test___init__(self):
-
-        pass
+        self.renderer = gaupol.gtk.TimeCellRenderer()
