@@ -9,19 +9,24 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
 """Base class for dialog-running classes."""
 
-__all__ = ["Runner"]
+__all__ = ("Runner",)
 
 
 class Runner(object):
 
-    """Base class for dialog-running classes."""
+    """Base class for dialog-running classes.
+
+    Using this base class and its methods to run dialogs allows unit testing to
+    override the methods with something that doesn't actually run the dialog,
+    but rather returns a response without user interaction.
+    """
 
     def flash_dialog(self, dialog):
         """Run dialog, destroy it and return response."""
