@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2007 Osmo Salomaa
+# Copyright (C) 2005-2008 Osmo Salomaa
 #
 # This file is part of Gaupol.
 #
@@ -9,23 +9,17 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
 import gaupol.gtk
 
-from gaupol.gtk import unittest
 
-
-class TestModule(unittest.TestCase):
+class TestModule(gaupol.gtk.TestCase):
 
     def test_attributes(self):
 
         assert hasattr(gaupol.gtk, "COMBO_SEPARATOR")
         assert hasattr(gaupol.gtk, "EXTRA")
-        assert hasattr(gaupol.gtk, "BUSY_CURSOR")
-        assert hasattr(gaupol.gtk, "HAND_CURSOR")
-        assert hasattr(gaupol.gtk, "INSERT_CURSOR")
-        assert hasattr(gaupol.gtk, "NORMAL_CURSOR")
