@@ -48,6 +48,7 @@ class Project(gaupol.Observable):
      * main-file-saved (project, main_file)
      * main-texts-changed (project, indices)
      * positions-changed (project, indices)
+     * preview-started (project, video_path, sub_path, output_path)
      * subtitles-changed (project, indices)
      * subtitles-inserted (project, indices)
      * subtitles-removed (project, indices)
@@ -68,6 +69,7 @@ class Project(gaupol.Observable):
         "main-file-saved",
         "main-texts-changed",
         "positions-changed",
+        "preview-started",
         "subtitles-inserted",
         "subtitles-removed",
         "subtitles-changed",
@@ -76,10 +78,12 @@ class Project(gaupol.Observable):
         "translation-texts-changed",)
 
     def __getattr__(self, name):
+        """Return methods delegated to an agent."""
 
         return self._delegations[name]
 
     def __init__(self, framerate=None, undo_limit=None):
+        """Initialize a Project object."""
 
         gaupol.Observable.__init__(self)
         framerate = framerate or gaupol.framerates.FPS_24
@@ -111,5 +115,6 @@ class Project(gaupol.Observable):
             for attr_name in attr_names:
                 attr_value = getattr(agent, attr_name)
                 if attr_name in self._delegations:
-                    raise ValueError("Agents overlap")
+                    raise ValueError("Multiple definitions of %s" 
+                        % repr(attr_name))
                 self._delegations[attr_name] = attr_value
