@@ -9,20 +9,23 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
-"""SubViewer 2.0 tag library."""
+"""Text markup for the SubViewer 2.0 format."""
 
 import gaupol
 
-from .subrip import SubRip
+__all__ = ("SubViewer2",)
 
 
-class SubViewer2(SubRip):
+class SubViewer2(gaupol.tags.SubRip):
 
-    """SubViewer 2.0 tag library."""
+    """Text markup for the SubViewer 2.0 format.
 
-    format = gaupol.FORMAT.SUBVIEWER2
+    SubViewer 2.0 format is assumed to contain the same markup as SubRip.
+    """
+
+    format = gaupol.formats.SUBVIEWER2
