@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2007 Osmo Salomaa
+# Copyright (C) 2005-2008 Osmo Salomaa
 #
 # This file is part of Gaupol.
 #
@@ -9,17 +9,16 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
-from .test_taglib import TestTagLibrary
-from .. import tmplayer
+import gaupol
 
 
-class TestTMPlayer(TestTagLibrary):
+class TestTMPlayer(gaupol.TestCase):
 
     def setup_method(self, method):
 
-        self.taglib = tmplayer.TMPlayer()
+        self.markup = gaupol.tags.new(gaupol.formats.TMPLAYER)
